==> leechcraft-0.3.65.tar.bz2: leechcraft-0.3.65/src/plugins/cstp/leechcraft_cstp_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>LeechCraft::Plugins::CSTP::AddTask</name>
    <message>
        <location filename="addtask.cpp" line="107"/>
        <source>Directory %1 doesn&apos;t exist, would you like to select another?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="110"/>
        <source>Directory %1 isn&apos;t readable, would you like to select another?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="113"/>
        <source>Directory %1 isn&apos;t writable, would you like to select another?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="116"/>
        <source>%1 isn&apos;t a directory at all, would you like to select another?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="125"/>
        <source>LeechCraft</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="157"/>
        <source>Select directory</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::CSTP</name>
    <message>
        <location filename="cstp.cpp" line="199"/>
        <source>CSTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="201"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="208"/>
        <source>Remove all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="217"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="224"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="231"/>
        <source>Start all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="238"/>
        <source>Stop all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="250"/>
        <source>File exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="251"/>
        <source>File %1 already exists, continue download?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::Core</name>
    <message>
        <location filename="core.cpp" line="51"/>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="52"/>
        <source>State</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="53"/>
        <source>Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="54"/>
        <source>Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="55"/>
        <source>ETA</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="56"/>
        <source>DTA</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="228"/>
        <source>Could not truncate file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="351"/>
        <source>%1% (%2 of %3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="356"/>
        <source>%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="364"/>
        <source>/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="463"/>
        <source>Could not open file </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::MainViewDelegate</name>
    <message>
        <location filename="mainviewdelegate.cpp" line="71"/>
        <source>Idle</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::Task</name>
    <message>
        <location filename="task.cpp" line="187"/>
        <source>Stopped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="task.cpp" line="189"/>
        <source>Finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="task.cpp" line="191"/>
        <source>Running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="task.cpp" line="212"/>
        <source>Task isn&apos;t initialized properly</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> leechcraft-0.3.80_rc20101221.tar.bz2: leechcraft-0.3.80_rc20101221/src/plugins/cstp/leechcraft_cstp_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AddTask</name>
    <message>
        <location filename="addtask.ui" line="13"/>
        <source>Add task</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="addtask.ui" line="21"/>
        <source>URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="addtask.ui" line="31"/>
        <source>Local path:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="addtask.ui" line="43"/>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="addtask.ui" line="55"/>
        <source>Filename:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="addtask.ui" line="65"/>
        <source>Comment:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::AddTask</name>
    <message>
        <location filename="addtask.cpp" line="107"/>
        <source>Directory %1 doesn&apos;t exist, would you like to select another?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="110"/>
        <source>Directory %1 isn&apos;t readable, would you like to select another?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="113"/>
        <source>Directory %1 isn&apos;t writable, would you like to select another?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="116"/>
        <source>%1 isn&apos;t a directory at all, would you like to select another?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="157"/>
        <source>Select directory</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::CSTP</name>
    <message>
        <location filename="cstp.cpp" line="206"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="213"/>
        <source>Remove all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="222"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="229"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="236"/>
        <source>Start all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="243"/>
        <source>Stop all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="255"/>
        <source>File exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="256"/>
        <source>File %1 already exists, continue download?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::Core</name>
    <message>
        <location filename="core.cpp" line="61"/>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="62"/>
        <source>State</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="63"/>
        <source>Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="417"/>
        <source>%1 (ETA: %2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="580"/>
        <source>Download finished: %1
%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="521"/>
        <source>Could not open file %1: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="277"/>
        <source>Could not truncate file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="429"/>
        <source>%1% (%2 of %3 at %4)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="433"/>
        <source>/s</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::MainViewDelegate</name>
    <message>
        <location filename="mainviewdelegate.cpp" line="71"/>
        <source>Idle</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::Task</name>
    <message>
        <location filename="task.cpp" line="213"/>
        <source>Stopped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="task.cpp" line="215"/>
        <source>Finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="task.cpp" line="217"/>
        <source>Running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="task.cpp" line="238"/>
        <source>Task isn&apos;t initialized properly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="task.cpp" line="476"/>
        <source>Error writing to file %1: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>cstpsettings</name>
    <message>
        <location filename="dummy.cpp" line="2"/>
        <source>Local settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="3"/>
        <location filename="dummy.cpp" line="7"/>
        <source>Behavior</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="4"/>
        <source>Alert about errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="5"/>
        <source>Network settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="6"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="8"/>
        <source>Use text transfer mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="9"/>
        <source>Identification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="10"/>
        <source>HTTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="11"/>
        <source>Login:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="12"/>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="13"/>
        <source>Custom user agent:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="14"/>
        <source>Predefined user agent:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="15"/>
        <source>Firefox 3.0.1 on Linux i686</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="16"/>
        <source>Internet Explorer 6.0 on Windows XP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="17"/>
        <source>Internet Explorer 7.0 on Windows Vista</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="18"/>
        <source>Internet Explorer 4.0 on Windows 98</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="19"/>
        <source>Internet Explorer 2.0 on Windows 95</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="20"/>
        <source>Konqueror 4.0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="21"/>
        <source>SeaMonkey 1.1.11 on Linux i686</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="22"/>
        <source>Opera 9.52 on Linux x86_64</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="23"/>
        <source>Wget 1.9.1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="24"/>
        <source>w3m 0.5.2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="25"/>
        <source>Lynx 2.8.7 with OpenSSL</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
